{% load static %}

<div class="aldryn-bootstrap3 aldryn-bootstrap3-context" data-context="{{ selects.name }}">
    <div class="btn-group js-btn-group-context-{{ selects.name }}" data-toggle="buttons">
        {% for item in selects %}
            {{ item }}
        {% endfor %}
    </div>
</div>

{# Available Variables #}
{# {{ item.choice_value }}: {{ item.choice_label }} #}
{# selected: {{ selects.value }}  #}
